#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2023-2-9 created
current_dir=$(readlink -f "$(dirname "$0")")
source "${current_dir}/const.sh"
source "${current_dir}/utils.sh"


function init_variable() {
	if [ ! -f "${INSTALL_PATH}/tools/log.sh" ]; then
	    echo "There is no log file(${INSTALL_PATH}/tools/log.sh), please check!"
		exit "${ERROR}"
	fi
	source "${INSTALL_PATH}/tools/log.sh"
	INSTALL_INI_PATH="${INSTALL_PATH}/config/install.ini"
	if [[ ! -f "${INSTALL_INI_PATH}" ]]; then
		echo_and_log "There is no configure file(${INSTALL_INI_PATH}), please check!" "${ERROR}"
		exit "${ERROR}"
	fi
    plugin_name="devtools"
	INSTALL_LOG_PATH="${INSTALL_PATH}/logs/install_plugins.log"
	INSTALL_PLUGIN_PATH="${INSTALL_PATH}/devkitplugins"
	# 插件压缩包存档路径
	PYTHON_PATH="${INSTALL_PATH}/tools/python_venv/bin/python3"
}

function main() {
	INSTALL_PATH="$1" # /opt/DevKit
	plugin_flag="$2"  # web
	init_variable
	if [[ "${plugin_flag}" == "web" ]]; then
		bash "${current_dir}/env_check.sh" "${INSTALL_PATH}" "${plugin_flag}"
		local check_res="$?"
        chmod 444 "${current_dir}/make_env_check_result.pyc"
        su - "devkit" -s /bin/bash -c "${PYTHON_PATH} ${current_dir}/make_env_check_result.pyc"
        local temp_env_json="${current_dir}/devtools_env_res.json"
        local final_env_json="${INSTALL_PATH}/devkitplugins/check_env_result/devtools_env_res.json"
        if [[ -f "${temp_env_json}" ]]; then
            mv "${temp_env_json}" "${final_env_json}"
            chmod 600 "${final_env_json}"
            chown "${DEVKIT_USER}":"${DEVKIT_USER}" "${final_env_json}"
        fi
        if [[ "${check_res}" != "${SUCCESS}" ]]; then
            echo_and_log "Check install Dependent Packages Failed" "${ERROR}" "${INSTALL_LOG_PATH}"
            exit "${ERROR}"
        else
            echo_and_log "Check install Dependent Packages Success" "${SUCCESS}" "${INSTALL_LOG_PATH}"
        fi
    else
    	# 磁盘空间大小检测
        echo_and_log "Check disk space" "${DOING}" "${INSTALL_LOG_PATH}"
        disk_space_check "${INSTALL_PATH}" "${INSTALL_SPACE_NEED}"
        if [ "$?" -ne "${SUCCESS}" ]; then
            echo_and_log "Check install path disk space Failed" "${ERROR}" "${INSTALL_LOG_PATH}"
            exit "${ERROR}"
        fi
        echo_and_log "Check install path disk space Success" "${SUCCESS}" "${INSTALL_LOG_PATH}"
	fi
	# 删除依赖检查配置文件
	if [[ -e "${INSTALL_PATH}/devkitplugins/${plugin_name}/deploy/devtools_env_res.ini" ]]; then
	    rm -rf "${INSTALL_PATH}/devkitplugins/${plugin_name}/deploy/devtools_env_res.ini"
	fi
}

main $@